# OTTO
Otto is a simple Boilerplate for Machine Learning projects integrated with MLflow that creates a basic directory structure to organize your code and data.

```
├── MLproject
├── README.md
├── conda.yaml
├── .env
├── .gitignore
├── data
│   ├── processed/
│   └── raw/
├── notebooks/
├── src/
│   ├── models/
│   │   └── model.py
├── data/
│   └── features/
└── tests/
```

## Usage

Simple install otto using pip as follows

`pip install otto-ml`

and use otto

`otto --name new-project`

or simple use it with out params and let otto guides you 😉

`otto`

and that's it!  😝


